@@ -21,7 +21,7 @@ use Excel::Writer::XLSX::Package::XMLwriter;
 use Excel::Writer::XLSX::Worksheet;
 
 our @ISA     = qw(Excel::Writer::XLSX::Package::XMLwriter);
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 
 ###############################################################################
@@ -72,11 +72,9 @@ sub _assemble_xml_file {
 
         my $index = 0;
         for my $drawing_object ( @{ $self->{_drawings} } ) {
-
             # Write the xdr:twoCellAnchor element.
             $self->_write_two_cell_anchor( ++$index, $drawing_object );
         }
-
     }
     else {
         my $index = 0;
@@ -103,12 +101,16 @@ sub _add_drawing_object {
     my $self = shift;
 
     my $drawing_object = {
-        _type       => undef,
-        _dimensions => [],
-        _width      => 0,
-        _height     => 0,
-        _shape      => undef,
-        _anchor     => undef
+        _type          => undef,
+        _dimensions    => [],
+        _width         => 0,
+        _height        => 0,
+        _description   => undef,
+        _shape         => undef,
+        _anchor        => undef,
+        _rel_index     => 0,
+        _url_rel_index => 0,
+        _tip           => undef
     };
 
     push @{ $self->{_drawings} }, $drawing_object;
@@ -179,9 +181,12 @@ sub _write_two_cell_anchor {
     my $row_absolute    = $dimensions->[9];
     my $width           = $drawing_object->{_width};
     my $height          = $drawing_object->{_height};
-    my $description     = $drawing_object->{_name};
+    my $description     = $drawing_object->{_description};
     my $shape           = $drawing_object->{_shape};
     my $anchor          = $drawing_object->{_anchor};
+    my $rel_index       = $drawing_object->{_rel_index};
+    my $url_rel_index   = $drawing_object->{_url_rel_index};
+    my $tip             = $drawing_object->{_tip};
 
     my @attributes = ();
 
@@ -221,13 +226,16 @@ sub _write_two_cell_anchor {
         # Graphic frame.
 
         # Write the xdr:graphicFrame element for charts.
-        $self->_write_graphic_frame( $index, $description );
+        $self->_write_graphic_frame( $index, $rel_index, $description );
     }
     elsif ( $type == 2 ) {
 
         # Write the xdr:pic element.
-        $self->_write_pic( $index, $col_absolute, $row_absolute, $width,
-            $height, $description );
+        $self->_write_pic(
+            $index,        $rel_index,     $col_absolute,
+            $row_absolute, $width,         $height,
+            $description,  $url_rel_index, $tip
+        );
     }
     else {
 
@@ -278,7 +286,7 @@ sub _write_absolute_anchor {
 
 
     # Write the xdr:graphicFrame element.
-    $self->_write_graphic_frame( $index );
+    $self->_write_graphic_frame( $index, $index );
 
     # Write the xdr:clientData element.
     $self->_write_client_data();
@@ -461,10 +469,11 @@ sub _write_ext {
 #
 sub _write_graphic_frame {
 
-    my $self  = shift;
-    my $index = shift;
-    my $name  = shift;
-    my $macro = '';
+    my $self      = shift;
+    my $index     = shift;
+    my $rel_index = shift;
+    my $name      = shift;
+    my $macro     = '';
 
     my @attributes = ( 'macro' => $macro );
 
@@ -477,7 +486,7 @@ sub _write_graphic_frame {
     $self->_write_xfrm();
 
     # Write the a:graphic element.
-    $self->_write_atag_graphic( $index );
+    $self->_write_atag_graphic( $rel_index );
 
     $self->xml_end_tag( 'xdr:graphicFrame' );
 }
@@ -519,22 +528,61 @@ sub _write_nv_graphic_frame_pr {
 #
 sub _write_c_nv_pr {
 
-    my $self  = shift;
-    my $id    = shift;
-    my $name  = shift;
-    my $descr = shift;
+    my $self          = shift;
+    my $index         = shift;
+    my $name          = shift;
+    my $description   = shift;
+    my $url_rel_index = shift;
+    my $tip           = shift;
 
     my @attributes = (
-        'id'   => $id,
+        'id'   => $index,
         'name' => $name,
     );
 
     # Add description attribute for images.
-    if ( defined $descr ) {
-        push @attributes, ( descr => $descr );
+    if ( defined $description ) {
+        push @attributes, ( descr => $description );
     }
 
-    $self->xml_empty_tag( 'xdr:cNvPr', @attributes );
+    if ($url_rel_index) {
+        $self->xml_start_tag( 'xdr:cNvPr', @attributes );
+
+        # Write the a:hlinkClick element.
+        $self->_write_a_hlink_click($url_rel_index, $tip);
+
+        $self->xml_end_tag( 'xdr:cNvPr');
+    }
+    else {
+        $self->xml_empty_tag( 'xdr:cNvPr', @attributes );
+    }
+
+}
+
+
+##############################################################################
+#
+# _write_a_hlink_click()
+#
+# Write the <a:hlinkClick> element.
+#
+sub _write_a_hlink_click {
+
+    my $self    = shift;
+    my $index   = shift;
+    my $tip     = shift;
+    my $schema  = 'http://schemas.openxmlformats.org/officeDocument/';
+    my $xmlns_r = $schema . '2006/relationships';
+    my $r_id    = 'rId' . $index;
+
+    my @attributes = (
+        'xmlns:r' => $xmlns_r,
+        'r:id'    => $r_id,
+    );
+
+    push( @attributes, ( 'tooltip' => $tip ) ) if $tip;
+
+    $self->xml_empty_tag('a:hlinkClick', @attributes );
 }
 
 
@@ -855,21 +903,25 @@ sub _write_nv_sp_pr {
 #
 sub _write_pic {
 
-    my $self         = shift;
-    my $index        = shift;
-    my $col_absolute = shift;
-    my $row_absolute = shift;
-    my $width        = shift;
-    my $height       = shift;
-    my $description  = shift;
+    my $self          = shift;
+    my $index         = shift;
+    my $rel_index     = shift;
+    my $col_absolute  = shift;
+    my $row_absolute  = shift;
+    my $width         = shift;
+    my $height        = shift;
+    my $description   = shift;
+    my $url_rel_index = shift;
+    my $tip           = shift;
 
     $self->xml_start_tag( 'xdr:pic' );
 
     # Write the xdr:nvPicPr element.
-    $self->_write_nv_pic_pr( $index, $description );
+    $self->_write_nv_pic_pr( $index, $rel_index, $description, $url_rel_index,
+        $tip );
 
     # Write the xdr:blipFill element.
-    $self->_write_blip_fill( $index );
+    $self->_write_blip_fill( $rel_index );
 
     # Pictures are rectangle shapes by default.
     my $shape = { _type => 'rect' };
@@ -890,14 +942,18 @@ sub _write_pic {
 #
 sub _write_nv_pic_pr {
 
-    my $self        = shift;
-    my $index       = shift;
-    my $description = shift;
+    my $self          = shift;
+    my $index         = shift;
+    my $rel_index     = shift;
+    my $description   = shift;
+    my $url_rel_index = shift;
+    my $tip           = shift;
 
     $self->xml_start_tag( 'xdr:nvPicPr' );
 
     # Write the xdr:cNvPr element.
-    $self->_write_c_nv_pr( $index + 1, 'Picture ' . $index, $description );
+    $self->_write_c_nv_pr( $index + 1, 'Picture ' . $index,
+        $description, $url_rel_index, $tip );
 
     # Write the xdr:cNvPicPr element.
     $self->_write_c_nv_pic_pr();
